from notecoin.okex.client import (AccountClient, AssetClient, MarketClient,
                                     PublicClient, SubAccountClient,
                                     SystemClient, TradeClient)
from notetool.secret import read_secret

api_key = read_secret(cate1='coin', cate2='okex', cate3='api_key')
secret_key = read_secret(cate1='coin', cate2='okex', cate3='secret_key')
passphrase = read_secret(cate1='coin', cate2='okex', cate3='passphrase')

# flag是实盘与模拟盘的切换参数 flag is the key parameter which can help you to change between demo and real trading.
# flag = True  # 模拟盘 demo trading
flag = False  # 实盘 real trading
account = AccountClient(api_key, secret_key, passphrase, False, flag)
fundingAPI = AssetClient(api_key, secret_key, passphrase, False, flag)
market = MarketClient(api_key, secret_key, passphrase, False, flag)
publicAPI = PublicClient(api_key, secret_key, passphrase, False, flag)


def test_account():
    print('查看账户持仓风险', account.get_position_risk('SWAP').data_size())
    print('查看账户余额', account.get_account().data_size())
    print('查看持仓信息', account.get_positions('FUTURES', 'BTC-USD-210402').data_size())
    # print('账单流水查询',account.get_bills_detail('FUTURES', 'BTC', 'cross').data_size())
    print('账单流水查询', account.get_bills_details('FUTURES', 'BTC', 'cross').data_size())
    print('查看账户配置', account.get_account_config().data_size())
    print('设置持仓模式', account.get_position_mode('long_short_mode').data_size())
    print('设置杠杆倍数', account.set_leverage(instId='BTC-USD-210402', lever='10', mgnMode='cross').data_size())
    # 获取最大可交易数量  Get Maximum Tradable Size For Instrument
    # result = account.get_maximum_trade_size('BTC-USDT-210402', 'cross', 'USDT')
    # 获取最大可用数量  Get Maximum Available Tradable Amount
    # result = account.get_max_avail_size('BTC-USDT-210402', 'isolated', 'BTC')
    # 调整保证金  Increase/Decrease margint
    # result = account.Adjustment_margin('BTC-USDT-210409', 'long', 'add', '100')
    # 获取杠杆倍数 Get Leverage
    # result = account.get_leverage('BTC-USDT-210409', 'isolated')
    # 获取币币逐仓杠杆最大可借  Get the maximum loan of isolated MARGIN
    # result = account.get_max_load('BTC-USDT', 'cross', 'BTC')

    print('获取当前账户交易手续费费率', account.get_fee_rates('FUTURES', '', category='1').data_size())
    # 获取计息记录  Get interest-accrued
    # result = account.get_interest_accrued('BTC-USDT', 'BTC', 'isolated', '', '', '10')
    # 获取用户当前杠杆借币利率 Get Interest-accrued
    # result = account.get_interest_rate()
    # 期权希腊字母PA / BS切换  Set Greeks (PA/BS)
    # result = account.set_greeks('BS')
    print('查看账户最大可转余额', account.get_max_withdrawal('').data_size())


def test_assert():
    # 获取充值地址信息  Get Deposit Address
    # result = fundingAPI.get_deposit_address('')
    # 获取资金账户余额信息  Get Balance
    # result = fundingAPI.get_balances('BTC')
    # 资金划转  Funds Transfer
    # result = fundingAPI.funds_transfer(ccy='', amt='', type='1', froms="", to="",subAcct='')
    # 提币  Withdrawal
    # result = fundingAPI.coin_withdraw('usdt', '2', '3', '', '', '0')
    print('充值记录', fundingAPI.get_deposit_history().data_size())
    print('提币记录', fundingAPI.get_withdrawal_history().data_size())
    print('获取币种列表 ', fundingAPI.get_currency().data_size())
    # 余币宝申购/赎回  PiggyBank Purchase/Redemption
    # result = fundingAPI.purchase_redempt('BTC', '1', 'purchase')

    print('资金流水查询', fundingAPI.get_bills().data_size())


def test_market():
    print('获取所有产品行情信息', market.get_tickers('SPOT').data_size())
    print('获取单个产品行情信息', market.get_ticker('BTC-USDT').data_size())
    print('获取指数行情', market.get_index_ticker('BTC', 'BTC-USD').data_size())
    print('获取产品深度', market.get_orderbook('BTC-USDT-210402', '400').data_size())
    print('获取所有交易产品K线数据', market.get_candlesticks('BTC-USDT-210924', bar='1m').data_size())
    print("获取交易产品历史K线数据（仅主流币实盘数据）", market.get_history_candlesticks('BTC-USDT').data_size())
    print("获取指数K线数据", market.get_index_candlesticks('BTC-USDT').data_size())
    print("获取标记价格K线数据", market.get_mark_price_candlesticks('BTC-USDT').data_size())
    print("获取交易产品公共成交数据", market.get_trades('BTC-USDT', '400').data_size())
    print("获取平台24小时成交总量", market.get_volume().data_size())
    print("Oracle 上链交易数据", market.get_oracle().data_size())


def test_public():
    print("获取交易产品基础信息", publicAPI.get_instruments('FUTURES', 'BTC-USDT'))
    print("获取交割和行权记录", publicAPI.get_deliver_history('FUTURES', 'BTC-USD'))
    print("获取持仓总量", publicAPI.get_open_interest('SWAP').data_size())
    print("获取永续合约当前资金费率", publicAPI.get_funding_rate('BTC-USD-SWAP'))
    print("获取永续合约历史资金费率", publicAPI.funding_rate_history('BTC-USD-SWAP'))
    print("获取限价", publicAPI.get_price_limit('BTC-USD-210402'))
    print("获取期权定价", publicAPI.get_opt_summary('BTC-USD'))
    print("获取预估交割/行权价格", publicAPI.get_estimated_price('ETH-USD-210326'))
    print("获取免息额度和币种折算率", publicAPI.discount_interest_free_quota(''))
    print("获取系统时间", publicAPI.get_system_time())
    print("获取平台公共爆仓单信息",
          publicAPI.get_liquidation_orders('FUTURES', uly='BTC-USDT', alias='next_quarter', state='filled'))
    print("获取标记价格", publicAPI.get_mark_price('FUTURES'))
    print("获取合约衍生品仓位档位", publicAPI.get_tier(instType='MARGIN', instId='BTC-USDT', tdMode='cross'))


def test_trade():
    tradeAPI = TradeClient(api_key, secret_key, passphrase, False, flag)
    # 下单  Place Order
    # result = tradeAPI.place_order(instId='BTC-USDT-210326', tdMode='cross', side='sell', posSide='short',
    #                               ordType='market', sz='100')
    # 批量下单  Place Multiple Orders
    # result = tradeAPI.place_multiple_orders([
    #     {'instId': 'BTC-USD-210402', 'tdMode': 'isolated', 'side': 'buy', 'ordType': 'limit', 'sz': '1', 'px': '17400',
    #      'posSide': 'long',
    #      'clOrdId': 'a12344', 'tag': 'test1210'},
    #     {'instId': 'BTC-USD-210409', 'tdMode': 'isolated', 'side': 'buy', 'ordType': 'limit', 'sz': '1', 'px': '17359',
    #      'posSide': 'long',
    #      'clOrdId': 'a12344444', 'tag': 'test1211'}
    # ])

    # 撤单  Cancel Order
    # result = tradeAPI.cancel_order('BTC-USD-201225', '257164323454332928')
    # 批量撤单  Cancel Multiple Orders
    # result = tradeAPI.cancel_multiple_orders([
    #     {"instId": "BTC-USD-210402", "ordId": "297389358169071616"},
    #     {"instId": "BTC-USD-210409", "ordId": "297389358169071617"}
    # ])

    # 修改订单  Amend Order
    # result = tradeAPI.amend_order()
    # 批量修改订单  Amend Multiple Orders
    # result = tradeAPI.amend_multiple_orders(
    #     [{'instId': 'BTC-USD-201225', 'cxlOnFail': 'false', 'ordId': '257551616434384896', 'newPx': '17880'},
    #      {'instId': 'BTC-USD-201225', 'cxlOnFail': 'false', 'ordId': '257551616652488704', 'newPx': '17882'}
    #      ])

    # 市价仓位全平  Close Positions
    # result = tradeAPI.close_positions('BTC-USDT-210409', 'isolated', 'long', '')
    # 获取订单信息  Get Order Details
    # result = tradeAPI.get_orders('BTC-USD-201225', '257173039968825345')

    print("获取未成交订单列表", tradeAPI.get_order_list().data_size())
    print("获取历史订单记录（近七天", tradeAPI.get_orders_history('FUTURES').data_size())
    print("获取历史订单记录（近三个月）", tradeAPI.orders_history_archive('FUTURES').data_size())
    # 获取成交明细  Get Transaction Details
    # result = tradeAPI.get_fills()
    # 策略委托下单  Place Algo Order
    # result = tradeAPI.place_algo_order('BTC-USDT-210409', 'isolated', 'buy', ordType='conditional',
    #                                    sz='100',posSide='long', tpTriggerPx='60000', tpOrdPx='59999')
    # 撤销策略委托订单  Cancel Algo Order
    # result = tradeAPI.cancel_algo_order([{'algoId': '297394002194735104', 'instId': 'BTC-USDT-210409'}])
    # 获取未完成策略委托单列表  Get Algo Order List
    # result = tradeAPI.order_algos_list('conditional', instType='FUTURES')
    # 获取历史策略委托单列表  Get Algo Order History
    # result = tradeAPI.order_algos_history('conditional', 'canceled', instType='FUTURES')


def test_sub_account():
    subAccountAPI = SubAccountClient(api_key, secret_key, passphrase, False, flag)
    print("查询子账户的交易账户余额(适用于母账户)", subAccountAPI.balances(subAcct='').data_size())
    print("查询子账户转账记录(仅适用于母账户)", subAccountAPI.bills().data_size())
    print("删除子账户APIKey(仅适用于母账户)", subAccountAPI.delete(pwd='', subAcct='', apiKey='').data_size())
    print("重置子账户的APIKey(仅适用于母账户)", subAccountAPI.reset(pwd='', subAcct='', label='', apiKey='', perm='').data_size())
    print("创建子账户的APIKey(仅适用于母账户)", subAccountAPI.create(pwd='123456', subAcct='', label='', Passphrase='').data_size())
    print("查看子账户列表(仅适用于母账户)", subAccountAPI.view_list().data_size())
    print("母账户控制子账户与子账户之间划转（仅适用于母账户）",
          subAccountAPI.control_transfer(ccy='', amt='', froms='', to='', fromSubAccount='',
                                         toSubAccount='').data_size())


def test_system():
    # 系统状态API(仅适用于实盘) system status
    status = SystemClient(api_key, secret_key, passphrase, False, flag)
    print("查看系统的升级状态", status.status())


if __name__ == '__main__':
    test_account()
    test_assert()
    test_public()
    test_market()



from .api_signature import create_signature, create_signature_v2, utc_now
from .channels import *
from .channels_request import *
from .input_checker import (check_currency, check_list, check_range,
                            check_should_none, check_should_not_none,
                            check_symbol, check_symbol_list, format_date,
                            greater_or_equal)
from .json_parser import (default_parse, default_parse_fill_directly,
                          default_parse_list_dict)
from .log_info import LogInfo, LogLevel
from .print_mix_object import PrintBasic, PrintList, PrintMix
from .time_service import (convert_cst_in_millisecond_to_utc,
                           convert_cst_in_second_to_utc, get_current_timestamp)



"""

"""
import json
import zipfile
from datetime import datetime

import pandas as pd
from notecoin.huobi.dataset.core import (Kline1DayDetail, Kline1MinDetail,
                                         Kline4HourDetail, Kline5MinDetail,
                                         Kline15MinDetail, Kline30MinDetail,
                                         Kline60MinDetail, KlineDetail,
                                         TradeDetail)
from notecoin.huobi.history.utils import *
from notetool.log import log, logger
from notetool.path import list_file, removedirs
from tqdm import tqdm

_SWAP = "swap"
_SPOT = "spot"
_FUTURE = "future"
_OPTION = "option"
_LINEARSWAP = "linear-swap"
ALL_TYPES = ["future", "spot", "swap",  "option", "linear-swap"]
ALL_DATA_TYPES = ['klines', 'trades']
ALL_PERIODS = ['1min', '5min', '15min', '30min', '60min', '4hour', '1day']
ALL_FREQ = ["daily"]
PRE_URL = "https://futures.huobi.com/data"

logger = log()


class Response:
    def __init__(self, status: bool = True, data: dict = None):
        self.status = status or True
        self.data = data or {}

    def success(self):
        self.status = True

    def error(self):
        self.status = False

    def put(self, key, value):
        self.data[key] = value

    def get(self, key):
        return self.data.get(key)

    def extend(self, data: dict = None):
        if isinstance(data, dict):
            self.data.update(data)


class HistoryDownload:
    def __init__(self,
                 pre_url=None,
                 data_type: str = None,
                 all_periods: list = None,
                 _type: str = None,
                 freq: str = None,
                 start_date=None,
                 end_date=None,
                 all_symbols=None,
                 download_dir=None
                 ):
        self.freq = freq or ALL_FREQ[0]
        self.type = _type or ALL_TYPES[0]
        self.pre_url = pre_url or PRE_URL
        self.data_type = data_type or ALL_DATA_TYPES[0]

        self.all_symbols = all_symbols
        self.download_dir = download_dir or "./data"
        self.all_periods = all_periods or ALL_PERIODS
        self.start_date = start_date or datetime(2017, 10, 27)
        self.end_date = end_date or datetime(2021, 7, 27)

    @staticmethod
    def _file_unzip(file_path) -> Response:
        """unzip zip file"""
        response = Response(True)
        zip_file = zipfile.ZipFile(file_path)
        file_dir = os.path.split(file_path)[0]
        for name in zip_file.namelist():
            zip_file.extract(name, path=file_dir)
            response.put('file_path', os.path.join(file_dir, name))
        zip_file.close()

        return response

    @staticmethod
    def _http_download(url: str, download_dir) -> Response:
        response = Response()
        try:
            if not os.path.exists(download_dir):
                os.makedirs(download_dir)
            if url is None:
                return Response(False, {"msg": 'url is null'})
            data = requests.get(url, allow_redirects=True)
            file_name = os.path.basename(url)
            file_path = os.path.join(download_dir, file_name)
            if len(data.content) > 30:
                with open(file_path, 'wb') as f:
                    f.write(data.content)
                response.put("file_path", file_path)
            else:
                response.error()
                response.put("file_path", "File not exists.")

        except Exception as e:
            response.put("download error", str(e))

        return response

    def init_parameters(self):
        print(self.type)
        if self.all_symbols is None:
            ok, all_symbols = False, []
            if self.type == _SPOT:
                ok, all_symbols = get_all_spot_symbols()
            elif self.type == _FUTURE:
                ok, all_symbols = get_all_future_symbols()
            elif self.type == _SWAP:
                ok, all_symbols = get_all_swap_symbols()
            elif self.type == _OPTION:
                ok, all_symbols = get_all_option_symbols()
            elif self.type == _LINEARSWAP:
                ok, all_symbols = get_all_linearswap_symbols()

            if not ok:
                logger.warning(all_symbols)

                return
            self.all_symbols = all_symbols

    def download_symbol_period_day(self, path_url, symbol, period, current,
                                   delete_zip=True,
                                   delete_check=True,
                                   *args, **kwargs) -> Response:
        url = f'{path_url}/{symbol.upper()}-{period}-{current.year}-{current.month:02}-{current.day:02}'
        download_dir = os.path.join(self.download_dir, self.data_type, self.type, period)
        if not os.path.exists(download_dir):
            os.makedirs(download_dir)
        zip_file = f'{url}.zip'
        check_file = f'{url}.CHECKSUM'
        response1 = self._http_download(zip_file, download_dir)
        response2 = self._http_download(check_file, download_dir)
        response = Response(response1.status)

        response.extend({
            "zip_url": zip_file,
            "zip_file": response1.get('file_path'),
            "check_url": check_file,
            "check_file": response2.get('file_path')
        })

        if response1.status:
            response3 = self._file_unzip(response1.get('file_path'))
            response3.put("file", response3.get('file_path'))
            if delete_zip:
                os.remove(response.get('zip_file'))
            if delete_check:
                os.remove(response.get('check_file'))

        return response

    def download_symbol_period(self, symbol, period, start_date=None, end_date=None, *args, **kwargs) -> tuple:
        if period in ['trades', ]:
            path_url = f'{self.pre_url}/{self.data_type}/{self.type}/{self.freq}/{symbol}'
        else:
            path_url = f'{self.pre_url}/{self.data_type}/{self.type}/{self.freq}/{symbol}/{period}'
        start_date = start_date or self.start_date
        end_date = end_date or self.end_date
        all_res = []
        interval = end_date - start_date + timedelta(days=1)
        if interval.days > 10:
            for index in tqdm(range(interval.days), desc=f'{symbol}'):
                current = start_date + timedelta(days=index)
                all_res.append(self.download_symbol_period_day(path_url, symbol, period, current, *args, **kwargs))
        else:
            for index in range(interval.days):
                current = start_date + timedelta(days=index)
                all_res.append(self.download_symbol_period_day(path_url, symbol, period, current, *args, **kwargs))
        all_oks = [response for response in all_res if response.status]
        all_errs = [response for response in all_res if not response.status]
        return all_oks, all_errs

    def download_symbols(self, all_symbols=None, all_periods=None, start_date=None, end_date=None, *args, **kwargs):
        """return date is: [start, end)"""
        self.init_parameters()
        all_symbols = all_symbols or self.all_symbols
        all_periods = all_periods or self.all_periods
        if len(all_symbols) > 10:
            for symbol in tqdm(all_symbols, desc='download symbols'):
                for period in all_periods:
                    all_oks, all_errs = self.download_symbol_period(symbol, period, start_date, end_date, *args,
                                                                    **kwargs)
                    logger.warning(f'success:{all_oks}')
                    logger.warning(f'failed:{all_errs}')
        else:
            for symbol in all_symbols:
                for period in all_periods:
                    all_oks, all_errs = self.download_symbol_period(symbol, period, start_date, end_date, *args,
                                                                    **kwargs)
                    logger.warning(f'success:{all_oks}')
                    logger.warning(f'failed:{all_errs}')
        logger.info('done')

    def download_klines(self, _type=None, *args, **kwargs):
        """return date is: [start, end)"""
        self.data_type = ALL_DATA_TYPES[0]
        self.type = _type or ALL_TYPES[0]
        self.download_symbols(*args, **kwargs)

    def download_trades(self, _type=None, *args, **kwargs):
        self.type = _type or ALL_TYPES[0]
        self.data_type = ALL_DATA_TYPES[1]
        self.all_periods = ['trades']
        self.download_symbols(*args, **kwargs)


class SymbolHistory:
    def __init__(self, dir_path='/root/workspace/tmp/coin/', symbol='SHIBUSDT'):
        self.db_path = os.path.join(dir_path, 'dbs', f'huobi-{symbol}.db')

        self.file_dir = os.path.join(dir_path, 'files')

        self.symbol = symbol
        self.tradeDB = TradeDetail(db_path=self.db_path)
        self.kline_1min = Kline1MinDetail(db_path=self.db_path, conn=self.tradeDB.conn)
        self.kline_5min = Kline5MinDetail(db_path=self.db_path, conn=self.tradeDB.conn)
        self.kline_15min = Kline15MinDetail(db_path=self.db_path, conn=self.tradeDB.conn)
        self.kline_30min = Kline30MinDetail(db_path=self.db_path, conn=self.tradeDB.conn)
        self.kline_60min = Kline60MinDetail(db_path=self.db_path, conn=self.tradeDB.conn)
        self.kline_4hour = Kline4HourDetail(db_path=self.db_path, conn=self.tradeDB.conn)
        self.kline_1day = Kline1DayDetail(db_path=self.db_path, conn=self.tradeDB.conn)
        self.init()

    def init(self):
        self.tradeDB.create()
        self.kline_1min.create()
        self.kline_5min.create()
        self.kline_15min.create()
        self.kline_30min.create()
        self.kline_60min.create()
        self.kline_4hour.create()
        self.kline_1day.create()

    def insert_trades(self, start_date, end_date):
        pass

    def insert_kline(self, kline_db: KlineDetail, file_path):
        try:
            df = pd.read_csv(file_path, index_col=None, header=None)
            df.columns = ['id', 'open', 'close', 'high', 'low', 'vol', 'amount']
            df['symbol'] = self.symbol
            kline_db.insert_list(json.loads(df.to_json(orient='records')))
        except Exception as e:
            logger.info(f'error file {file_path}')
            print(e)

    def insert_klines(self, start_date, end_date):

        self.insert_kline(self.kline_1min, load_symbol_all(symbol=self.symbol, start_date=start_date,
                                                           end_date=end_date, period='1min'))
        self.insert_kline(self.kline_5min, load_symbol_all(symbol=self.symbol, start_date=start_date,
                                                           end_date=end_date, period='5min'))
        self.insert_kline(self.kline_15min, load_symbol_all(symbol=self.symbol, start_date=start_date,
                                                            end_date=end_date, period='15min'))
        self.insert_kline(self.kline_30min, load_symbol_all(symbol=self.symbol, start_date=start_date,
                                                            end_date=end_date, period='30min'))
        self.insert_kline(self.kline_60min, load_symbol_all(symbol=self.symbol, start_date=start_date,
                                                            end_date=end_date, period='60min'))
        self.insert_kline(self.kline_4hour, load_symbol_all(symbol=self.symbol, start_date=start_date,
                                                            end_date=end_date, period='4hour'))
        self.insert_kline(self.kline_1day, load_symbol_all(symbol=self.symbol, start_date=start_date,
                                                           end_date=end_date, period='1day'))

    def insert_data(self, start_date, end_date):
        self.insert_trades(start_date, end_date)
        self.insert_klines(start_date, end_date)

        print(self.tradeDB.select('select count(1) as num from ' + self.tradeDB.table_name))
        print("1min\t{}".format(self.kline_1min.select('select count(1) as num from ' + self.kline_1min.table_name)))
        print("5min\t{}".format(self.kline_5min.select('select count(1) as num from ' + self.kline_5min.table_name)))
        print("15min\t{}".format(self.kline_15min.select('select count(1) as num from ' + self.kline_15min.table_name)))
        print("30min\t{}".format(self.kline_30min.select('select count(1) as num from ' + self.kline_30min.table_name)))
        print("60min\t{}".format(self.kline_60min.select('select count(1) as num from ' + self.kline_60min.table_name)))
        print("4hour\t{}".format(self.kline_4hour.select('select count(1) as num from ' + self.kline_4hour.table_name)))
        print("1day\t{}".format(self.kline_1day.select('select count(1) as num from ' + self.kline_1day.table_name)))

    def run(self, start_date=datetime(2021, 5, 25), end_date=datetime(2021, 6, 23)):
        self.insert_data(start_date, end_date)

    def test(self):
        import pandas as pd
        condition = 'id>=1619400078439 and id<=1619452799999 limit 111'
        sql = "select * from {} where {}".format(self.kline_1day.table_name, condition)
        print(sql)
        result = pd.read_sql(sql=sql, con=self.kline_1day.conn)
        print(result.head(10))


def load_daily_all(period='1min',
                   data_type=ALL_DATA_TYPES[0],
                   _type=ALL_TYPES[0],
                   date=datetime(2021, 5, 21),
                   download_dir='/root/workspace/tmp/coin/daily',
                   delete_file=True,
                   overwrite=False):
    download_dir2 = os.path.join(download_dir, date.strftime("%Y%m%d"))
    history = HistoryDownload(all_symbols=None,
                              data_type=data_type,
                              all_periods=[period],
                              _type=_type,
                              start_date=date,
                              end_date=date,
                              download_dir=download_dir2)
    file_path = os.path.join(download_dir, f'{history.data_type}_{history.type}_{period}-{date.strftime("%Y%m%d")}.csv')
    if os.path.exists(file_path) and not overwrite:
        return file_path
    if history.data_type == 'trade':
        history.download_trades()
    else:
        history.download_klines()

    with open(file_path, 'w') as new_file:
        for item in list_file(download_dir2, deep=10):
            symbol = os.path.basename(item).split('-')[0]
            for txt in open(item, 'r'):
                txt.replace('\n', f'\n{symbol},')
                new_file.write(f'{symbol},{txt}')

    if delete_file:
        removedirs(download_dir2)
    return file_path


def load_symbol_all(symbol='SHIBUSDT',
                    period='1min',
                    _type=ALL_TYPES[0],
                    data_type=ALL_DATA_TYPES[0],
                    start_date=datetime(2021, 5, 1),
                    end_date=datetime(2021, 5, 23),
                    download_dir='/root/workspace/tmp/coin/symbol',
                    delete_file=True):
    download_dir2 = os.path.join(download_dir, symbol)
    history = HistoryDownload(all_symbols=[symbol],
                              data_type=data_type,
                              all_periods=[period],
                              start_date=start_date,
                              end_date=end_date,
                              _type=_type,
                              download_dir=download_dir2)
    history.download_klines()
    file_path = os.path.join(download_dir, f'{history.data_type}_{history.type}_{period}-{symbol}.csv')
    with open(file_path, 'w') as new_file:
        for item in list_file(download_dir2, deep=10):
            for txt in open(item, 'r'):
                new_file.write(txt)

    if delete_file:
        removedirs(download_dir2)
    return file_path


def load_symbol_all_to_db(symbol='SHIBUSDT',
                          start_date=datetime(2021, 5, 1),
                          end_date=datetime(2021, 5, 3)):
    history = SymbolHistory(symbol=symbol)
    history.run(start_date=start_date, end_date=end_date)
    return history.db_path



from fastapi import APIRouter
from notebuild.tool.fastapi import add_api_routes, api_route
from notecoin.okex.database.client import OkexClientAccountBalance


class BaseAPI(APIRouter):
    def __init__(self, prefix='/base', *args, **kwargs):
        super(BaseAPI, self).__init__(prefix=prefix, *args, **kwargs)
        add_api_routes(self)

    @api_route('/account/balance/update', description="AccountBalance")
    def account_balance_update(self):
        return OkexClientAccountBalance.update()
